@@ -10,7 +10,7 @@ Various Format descriptions for MagPy.
 """
 
 # import order matters - NamedTemporaryFile must be one of the first!
-__all__ = ['lib','opt','stream','absolutes','transfer','database','gui','collector'
+__all__ = ['lib','opt','stream','absolutes','transfer','database','collector'
 ]
 from magpy.stream import *
 from magpy.absolutes import *
@@ -19,5 +19,5 @@ from magpy.database import *
 
 import lib
 import opt
-import gui
 import collector
+
