@@ -724,11 +724,11 @@ class AbsoluteData(object):
             loggerabs.debug("_calcinc: Using F from provided scalar path") 
         else:
             #meanf = 0.
+            loggerabs.warning("_calcinc: No F measurements found - using annual means ...") 
             meanf = (annualmeans[0]*annualmeans[0] + annualmeans[1]*annualmeans[1] + annualmeans[2]*annualmeans[2])
             #return emptyline, 20000.0, 0.0
 
         
-
         if len(variox) == 0:
             if iterator == 0:
                 loggerabs.warning("_calcinc: %s : no variometervalues found" % num2date(self[0].time).replace(tzinfo=None))
@@ -1026,7 +1026,14 @@ class AbsoluteData(object):
             if debugmode:
                 print "Calculated I (%f) - iteration step %d" %(outline[1],i)
 
-
+        # Temporary cleanup for extraordinary high values (failed calculations) - replace by 999999.99
+        for key in FLAGKEYLIST:
+             if not 'time' in key:
+                 testval = eval('outline.'+key)
+                 #print testval
+                 if testval > 10000000:
+                     exec('outline.'+key+' = 999999.99')
+        
         #test whether outline is a linestruct object - if not use an empty object
         try:
             test = outline.x
@@ -1740,17 +1747,42 @@ def absoluteAnalysis(absdata, variodata, scalardata, **kwargs):
         
     if readfile:
         # Get list of files
-        if "://" in absdata:
-            print "Found URL code - requires name of data set with date" 
-            filelist.append(absdata)
-            movetoarchive = False # XXX No archiving function supported so far - will be done as soon as writing to files is available
-        elif os.path.isfile(absdata):
-            print "Found single file"
-            filelist.append(absdata)
+        if isinstance(absdata, basestring):
+            #print "Found string"
+            #filelist.append(absdata)
+            if "://" in absdata:
+                print "Found URL code - requires name of data set with date" 
+                filelist.append(absdata)
+                movetoarchive = False # XXX No archiving function supported so far - will be done as soon as writing to files is available
+            elif os.path.isfile(absdata):
+                #print "Found single file"
+                filelist.append(absdata)
+            else:
+                if os.path.exists(absdata):
+                    pass
+                else:
+                    print "absolute Analysis: Error - path to absdata not existing: %s" % absdata
+                    sys.exit()
+                for file in os.listdir(absdata):
+                    if file.endswith(diid):
+                        filelist.append(os.path.join(absdata,file))
         else:
-            for file in os.listdir(absdata):
-                if file.endswith(diid):
-                    filelist.append(os.path.join(absdata,file))
+            try:
+                #print "Found List"
+                listlen = len(absdata)
+                for elem in absdata:
+                    if "://" in absdata:
+                        print "Found URL code - requires name of data set with date" 
+                        filelist.append(elem)
+                        movetoarchive = False # XXX No archiving function supported so far - will be done as soon as writing to files is available
+                    elif os.path.isfile(elem):
+                        #print "Found single file"
+                        filelist.append(elem)
+            except:
+                print "Could not interpret absdata"
+                return
+
+             
 
         for elem in filelist:
             head, tail = os.path.split(elem)
@@ -1781,6 +1813,7 @@ def absoluteAnalysis(absdata, variodata, scalardata, **kwargs):
     # read varios, scalar and all absfiles of one day
     # analyze data for each day and append results to a resultstream    
     # XXX possible issues: an absolute measurement which is performed in two day (e.g. across midnight)
+    # TODO Add possibilty to get vario and scalar data from database
     resultstream = DataStream()
     for date in sorted(datetimelist):
         variofound = True
@@ -1790,8 +1823,12 @@ def absoluteAnalysis(absdata, variodata, scalardata, **kwargs):
         print "Starting analysis for ", date
         print "------------------------------------------------------"
         # a) Read variodata
-        variostr = read(variodata,starttime=date,endtime=date+timedelta(days=1))
-        print "Length of Variodata:", len(variostr)
+        try:
+            variostr = read(variodata,starttime=date,endtime=date+timedelta(days=1))
+            print "Length of Variodata:", len(variostr)
+        except:
+            print "absoluteAnalysis: reading variometer data failed"
+            variostr = DataStream()
         if len(variostr) > 3: # can contain ([], 'File not specified')
             variostr =variostr.rotation(alpha=alpha, beta=beta)
             vafunc = variostr.interpol(['x','y','z'])
@@ -1801,8 +1838,12 @@ def absoluteAnalysis(absdata, variodata, scalardata, **kwargs):
             
         # b) Load Scalardata
         print "-----------------"
-        scalarstr = read(scalardata,starttime=date,endtime=date+timedelta(days=1))
-        print "Length of Scalardata:", len(scalarstr)
+        try:
+            scalarstr = read(scalardata,starttime=date,endtime=date+timedelta(days=1))
+            print "Length of Scalardata:", len(scalarstr)
+        except:
+            print "absoluteAnalysis: reading scalar data failed"
+            scalarstr = DataStream()
         if len(scalarstr) > 3: # Because scalarstr can contain ([], 'File not specified')
             scfunc = scalarstr.interpol(['f'])
         else:
@@ -1870,22 +1911,33 @@ def absoluteAnalysis(absdata, variodata, scalardata, **kwargs):
                 stream = stream._insert_function_values(vafunc)
             if scalarfound:
                 stream = stream._insert_function_values(scfunc,funckeys=['f'],offset=deltaF)
-            result = stream.calcabsolutes(usestep=usestep,annualmeans=annualmeans,printresults=True,debugmode=False)
+            try:
+                result = stream.calcabsolutes(usestep=usestep,annualmeans=annualmeans,printresults=True,debugmode=False)
+            except:
+                result = LineStruct()
             dataok = True
             if expD:
                 if not expD-expT < result.y < expD+expT:
-                    test = datetime.strftime(num2date(stream[0].time),'%Y-%m-%d_%H-%M-%S')
-                    xl = [ el for el in difiles if test in el]
-                    failinglist.append(xl[0])
-                    print "absoluteAnalysis: Failed to analyse %s - threshold for acceptable angular offset exceeded" % test
-                    dataok = False
+                    try:
+                        test = datetime.strftime(num2date(stream[0].time),'%Y-%m-%d_%H-%M-%S')
+                        xl = [ el for el in difiles if test in el]
+                        failinglist.append(xl[0])
+                        print "absoluteAnalysis: Failed to analyse %s - threshold for acceptable angular offset exceeded" % test
+                        dataok = False
+                    except:
+                        print "absoluteAnalysis: Value error while determining time - failed analysis"
+                        dataok = False
             if expI and dataok:
                 if not expI-expT < result.x < expI+expT:
-                    test = datetime.strftime(num2date(stream[0].time),'%Y-%m-%d_%H-%M-%S')
-                    xl = [ el for el in difiles if test in el]
-                    failinglist.append(xl[0])
-                    print "absoluteAnalysis: Failed to analyse %s - threshold for acceptable angular offset exceeded" % test
-                    dataok = False
+                    try:
+                        test = datetime.strftime(num2date(stream[0].time),'%Y-%m-%d_%H-%M-%S')
+                        xl = [ el for el in difiles if test in el]
+                        failinglist.append(xl[0])
+                        print "absoluteAnalysis: Failed to analyse %s - threshold for acceptable angular offset exceeded" % test
+                        dataok = False
+                    except:
+                        print "absoluteAnalysis: Value error while determining time - failed analysis"
+                        dataok = False
             if dataok:
                 resultstream.add(result)
 
@@ -1992,9 +2044,6 @@ def absoluteAnalysis(absdata, variodata, scalardata, **kwargs):
     return resultstream
 
 
-
-
-
 def getAbsFilesFTP(**kwargs):
     """
     Obtain files from the selected directory
@@ -2098,34 +2147,10 @@ def removeAbsFilesFTP(**kwargs):
 # ------------------
 # ##################
 
-localpath = os.path.normpath(r'e:\leon\Programme\Python\PyMag\ExperimentalFolder')
-ftppath = '/cobenzlabs'
-filestr = 'test'
-#myproxy = '94.136.40.103'
-#port = 21
-login = 'data@conrad-observatory.at'
-myproxy = '138.22.156.44'
-#port = 8021
-login = 'data@conrad-observatory.at@94.136.40.103'
-
 
 if __name__ == '__main__':
     print "Starting a test of the Absolutes program:"
     #msg = PyMagLog()
-    # getAbsFTP()
-    #st = analyzeAbsFiles(path_or_url=testpath, variopath=variopath, scalarpath=variopath)
-    #st = analyzeAbsFiles(path_or_url=os.path.normpath(r'e:\leon\Programme\Python\PyMag\ExperimentalFolder'), alpha=3.25, beta=0.0, variopath=variopath, scalarpath=scalarpath)
-    #st = analyzeAbsFiles(path_or_url=os.path.normpath(r'e:\leon\Programme\Python\PyMag\ExperimentalFolder'), alpha=3.25, beta=0.0, variopath=os.path.normpath('..\\dat\\lemi025\\*'), scalarpath=os.path.normpath('..\\dat\\didd\\*'), archivepath=os.path.normpath('..\\dat\\absolutes\\analyzed'))
-    #st.write(analysispath,coverage='all',mode='replace',filenamebegins='absolutes_didd')
+    ### TODO: To be implemented
 
-    #loglst = msg.combineWarnLog(msg.warnings,msg.logger)
-    #print loglst
-
-    #newst = read(path_or_url=summarypath)
-    #newst.plot(['x','y','z'])
-    #print newst.header
-
-    ### ToDo
-    # test for input variations (e.g. no f, scalevals, lemi vs didd etc)
-    # eventually develop plot routine for absstruct....
 
