@@ -6,8 +6,8 @@ MagPy - Plot analyzed DI data
 import sys
 sys.path.append('/home/leon/Software/magpy/trunk/src')
 
-from stream import *   
-from transfer import *
+from magpy.stream import *   
+from magpy.transfer import *
 
 abspath = '/home/leon/Dropbox/Daten/Magnetism/DI-WIC/data/WIC-A2-FGE_S025_01.txt'
 absst = read(path_or_url=abspath)
