@@ -24,7 +24,7 @@ def isPYCDF(filename):
     except:
         return False
 
-    loggerlib.debug("format_magpy: Found PYCDF file %s" % filename)
+    #loggerlib.debug("format_magpy: Found PYCDF file %s" % filename)
     return True
 
 
@@ -39,7 +39,7 @@ def isPYSTR(filename):
     if not temp.startswith(' # MagPy - ASCII'):
         return False
 
-    loggerlib.debug("format_magpy: Found PYSTR file %s" % filename)
+    #loggerlib.debug("format_magpy: Found PYSTR file %s" % filename)
     return True
 
 
@@ -54,7 +54,7 @@ def isPYBIN(filename):
     if not temp.startswith('# MagPyBin'):
         return False
 
-    loggerlib.debug("format_magpy: Found PYBIN file %s" % filename)
+    #loggerlib.debug("format_magpy: Found PYBIN file %s" % filename)
     return True
 
 
@@ -175,6 +175,7 @@ def readPYCDF(filename, headonly=False, **kwargs):
     # DTU type is using different date format (MATLAB specific)
     # MagPy type is using datetime objects
     if getfile:
+        loggerlib.info("read: %s Format: PYCDF" % filename)
         try:
             cdfformat = cdf_file.attrs['DataFormat']
         except:
@@ -190,7 +191,7 @@ def readPYCDF(filename, headonly=False, **kwargs):
         #    cdf_file.close()
         #    return DataStream(stream, stream.header)    
 
-        logging.info(' Read: %s Format: %s ' % (filename, cdfformat))
+        loggerlib.info('Read: %s Format: %s ' % (filename, cdfformat))
 
         for key in cdf_file:
             # first get time or epoch column
@@ -309,8 +310,6 @@ def readPYBIN(filename, headonly=False, **kwargs):
     endtime = kwargs.get('endtime')
     getfile = True
 
-    loggerlib.info('readPYBIN: Reading Magpy binary data.')
-
     stream = DataStream([],{})
 
     theday = extractDateFromString(filename)
@@ -324,8 +323,10 @@ def readPYBIN(filename, headonly=False, **kwargs):
     except:
         # Date format not recognized. Need to read all files
         getfile = True 
+    logbaddata = False
 
     if getfile:
+        loggerlib.info("read: %s Format: PYCDF" % filename)
         fh = open(filename, 'rb')
         # read header line and extract packing format
         header = fh.readline()
@@ -341,8 +342,8 @@ def readPYBIN(filename, headonly=False, **kwargs):
             nospecial = True
             try:
                 if not keylist:
-                    loggerlib.error('keylist of length elemlist must be specified')
-                    return
+                    loggerlib.error('readPYBIN: keylist of length(elemlist) needs to be specified')
+                    return stream
                 elemlist = h_elem[3].strip('[').strip(']').split(',')
                 unitlist = h_elem[4].strip('[').strip(']').split(',')
                 multilist = map(float,h_elem[5].strip('[').strip(']').split(','))
@@ -410,18 +411,26 @@ def readPYBIN(filename, headonly=False, **kwargs):
                     data= struct.unpack(packstr, line)
                 except:
                     print "readPYBIN: struct error", filename, packstr, struct.calcsize(packstr)
-                time = datetime(data[0],data[1],data[2],data[3],data[4],data[5],data[6])
-                row = LineStruct()
-                row.time = date2num(stream._testtime(time))
-                for idx, elem in enumerate(elemlist):
-                    exec('row.'+keylist[idx]+' = data[idx+7]/float(multilist[idx])')
-                stream.add(row)
+                try:
+                    time = datetime(data[0],data[1],data[2],data[3],data[4],data[5],data[6])
+                    row = LineStruct()
+                    row.time = date2num(stream._testtime(time))
+                    for idx, elem in enumerate(elemlist):
+                        exec('row.'+keylist[idx]+' = data[idx+7]/float(multilist[idx])')
+                    stream.add(row)
+                    if logbaddata == True:
+                        loggerlib.error("readPYBIN: Good data resumes with: %s" % str(data))
+                        logbaddata = False
+                except:
+                    loggerlib.error("readPYBIN: Error in line while reading data file. Last line at: %s" % str(lastdata))
+                    logbaddata = True
+                lastdata = data
                 line = fh.read(length)
         else:
             print "To be done ..."
             pass
 
-    #print stream.header        
+    #print stream.header     
     return stream 
 
 
